declare enum LogLevel {
    all = -1,
    debug = 0,
    info = 1,
    warn = 2,
    error = 3,
    fatal = 4,
    off = Infinity
}
declare const LogLevelAlias: Record<string, LogLevel>;
interface LogMessage {
    level: LogLevel;
    name: string;
    messages: any[];
    line?: number;
    file?: string;
    timestamp?: number;
}
declare type LogHandler = (msg: LogMessage) => void;
interface LoggerInterface {
    (...messages: any[]): void;
    /** @deprecated use .level = LogLevel.off or LogLevel.all */
    active: boolean;
    level: LogLevel;
    debug(...messages: any[]): void;
    info(...messages: any[]): void;
    warn(...messages: any[]): void;
    error(...messages: any[]): void;
    assert(cond: any, ...messages: any[]): void;
    /** @deprecated use .assert */
    assertEqual(value: any, expected: any, ...args: any[]): void;
    /** @deprecated use .assert */
    assertNotEqual(value: any, expected: any, ...args: any[]): void;
    extend(prefix: string): LoggerInterface;
    factory?: LoggerContextInterface;
}
interface LoggerContextInterface {
    (name?: string): LoggerInterface;
    registerHandler(handler: LogHandler): void;
    setFilter(namespaces: string): void;
    setHandlers(handlers?: (LogHandler | undefined | null)[]): void;
    setLock(lock: boolean): void;
    setLogLevel(level?: LogLevel): void;
    setFactory(factory: (name?: string) => LoggerInterface): void;
}
interface LogHandlerOptions {
    level?: LogLevel;
    filter?: string;
    colors?: boolean;
    levelHelper?: boolean;
    nameBrackets?: boolean;
    padding?: number;
    fill?: number;
    stack?: boolean | number;
}
declare function LoggerContext(prefix?: string): LoggerContextInterface;

declare global {
    interface ZeedGlobalContext {
        logger?: any;
    }
}
declare const Logger: LoggerContextInterface;

export { Logger as L, LogLevel as a, LogLevelAlias as b, LogMessage as c, LogHandler as d, LoggerInterface as e, LoggerContextInterface as f, LogHandlerOptions as g, LoggerContext as h };
